@@ -3,21 +3,21 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '0.001005'; # VERSION
+our $VERSION = '0.001006'; # VERSION
 
 use MooseX::Types -declare => [ qw( CreditCard CardSecurityCode ) ];
 use MooseX::Types::Moose qw( Str Int );
 use MooseX::Types::Common::String 0.001005 qw( NumericCode );
+use Class::Load qw( load_class );
 use namespace::autoclean;
 
-use Business::CreditCard;
-
 subtype CreditCard,
 	as NumericCode,
 	where {
 		length($_) <= 20
 		&& length $_ >= 12
-		&& validate($_)
+		&& load_class('Business::CreditCard')
+		&& Business::CreditCard::validate($_)
 	},
 	message {'"'. $_ . '" is not a valid credit card number' }
 	;
@@ -48,8 +48,8 @@ subtype CardSecurityCode,
 
 # ABSTRACT: Moose Types related to Credit Cards
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -58,7 +58,7 @@ MooseX::Types::CreditCard - Moose Types related to Credit Cards
 
 =head1 VERSION
 
-version 0.001005
+version 0.001006
 
 =head1 SYNOPSIS
 
@@ -146,4 +146,3 @@ This is free software, licensed under:
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
